/*
* THIS SOFTWARE AND DOCUMENTATION ARE PROVIDED AS IS.  BITFLASH GRAPHICS INC.
* (BITFLASH) ASSUMES NO RESPONSIBILITY FOR THE ACCURACY OR COMPLETENESS OF THE
* DOCUMENTATION AND EXPRESSLY DISCLAIMS ALL REPRESENTATIONS AND WARRANTIES OF ANY
* KIND REGARDING THE CONTENT OR USE OF THE SOFTWARE OR DOCUMENTATION INCLUDING,
* BUT NOT LIMITED TO, EXPRESS AND IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS
* FOR A PARTICULAR USE, OR NON-INFRINGEMENT.
*
* IN NO EVENT WILL BITFLASH BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL,
* INCIDENTAL OR CONSEQUENTIAL DAMAGES, INCLUDING LOST PROFITS, LOST BUSINESS OR
* LOST DATA, RESULTING FROM THE USE OF OR RELIANCE UPON THE SOFTWARE OR
* DOCUMENTATION, WHETHER OR NOT BITFLASH HAS BEEN ADVISED OF THE POSSIBILITY OF
* SUCH DAMAGES.
*/

package com.bitflash.jabber.client.gui;

import java.awt.*;
import java.awt.event.*;

import com.bitflash.jabber.client.gui.whiteboard.*;
import com.bitflash.jabber.client.model.jabber.*;

class ChatWindow extends Frame implements ActionListener, WindowListener 
{
	ChatWindow( ChatManager manager, String to, String threadID )
	{
		this.manager = manager;
		this.threadID = threadID;
		this.to = to;
		
		setTitle( to );
		setLayout( new GridLayout(1,2) );
		addWindowListener( this );

		Panel textPanel = new Panel();
		textPanel.setLayout( new GridLayout(2,1) );
		
			sessionBox = new TextArea();
			sessionBox.setEditable( false );
			
		textPanel.add( sessionBox );
								
			entryBox = new TextField();
			entryBox.addActionListener( this );
			
		textPanel.add( entryBox );				
		add( textPanel );
		
		whiteboard = new WhiteboardControl( this, manager );
		add( whiteboard );
		
		pack();
		show();		
	}
		
	void jabberMessage( String from, String message )
	{
		if( from.equals("") )
			from = "SERVER";
		sessionBox.append( "<" + from + "> " + message + "\n" );
	}
	
	void jabberPresence( String nickname, Presence presence )
	{		
		if( null != presence.getChild( "x", X.XMLNS_WHITEBOARD ) )
			sessionBox.append( "%%" + nickname + " is " + (String)presence.getProperty( "type" ) + "%%\n" );
		
		whiteboard.presence( presence );
	}
		
	void whiteboardCommand( Message message )
	{
		whiteboard.command( message );
	}
	
	public void actionPerformed( ActionEvent event )
	{		
		manager.sendMessage( this, entryBox.getText() );
		entryBox.setText("");
	}
	
	public void windowClosed(WindowEvent event)
		{ manager.windowClosed(this); }

	public void windowClosing(WindowEvent event) 
	{ 
		whiteboard.close();
		dispose(); 
	}
	
	public void windowDeiconified(WindowEvent event){}
	public void windowIconified(WindowEvent event){}
	public void windowActivated(WindowEvent event){}
	public void windowDeactivated(WindowEvent event){}
	public void windowOpened(WindowEvent event){ whiteboard.open(); }	

	WhiteboardControl whiteboard;
	ChatManager manager;
	
	TextArea sessionBox;
	TextField entryBox;
	
	String threadID;
	String to;
}
