/*
* THIS SOFTWARE AND DOCUMENTATION ARE PROVIDED AS IS.  BITFLASH GRAPHICS INC.
* (BITFLASH) ASSUMES NO RESPONSIBILITY FOR THE ACCURACY OR COMPLETENESS OF THE
* DOCUMENTATION AND EXPRESSLY DISCLAIMS ALL REPRESENTATIONS AND WARRANTIES OF ANY
* KIND REGARDING THE CONTENT OR USE OF THE SOFTWARE OR DOCUMENTATION INCLUDING,
* BUT NOT LIMITED TO, EXPRESS AND IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS
* FOR A PARTICULAR USE, OR NON-INFRINGEMENT.
*
* IN NO EVENT WILL BITFLASH BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL,
* INCIDENTAL OR CONSEQUENTIAL DAMAGES, INCLUDING LOST PROFITS, LOST BUSINESS OR
* LOST DATA, RESULTING FROM THE USE OF OR RELIANCE UPON THE SOFTWARE OR
* DOCUMENTATION, WHETHER OR NOT BITFLASH HAS BEEN ADVISED OF THE POSSIBILITY OF
* SUCH DAMAGES.
*/

package com.bitflash.jabber.client.gui;

import java.util.*;
import com.bitflash.jabber.client.model.jabber.*;

public class GroupChatManager extends ChatManager
{	
	public GroupChatManager( Main parent )
	{
		super( parent );		
	}
	
	ChatWindow createSession( String remoteJabberID )
	{				
		// Say hello to the groupchat transport
		Presence presence = new Presence();
		presence.setProperty( "to", remoteJabberID + '/' + bareNickname(jabberID()) );
		parent.send( presence );
		
		return super.createSession( remoteJabberID, "" );
	}
	
	public void windowClosed( ChatWindow window )
	{
		// Say goodbye to the groupchat transport
		Presence presence = new Presence();
		presence.setProperty( "to", window.to + '/' + bareNickname(jabberID()) );
		presence.setProperty( "type", "unavailable" );
		parent.send( presence );
		
		super.windowClosed( window );		
	}
	
	void unknownSession( Message message )
	{
		// Do nothing
	}
	
	boolean jabberPresence( Presence presence )
	{	
		String from = presence.fromNickname();
		String nickname = nickname( (String)presence.getProperty("from") );
	
		synchronized( windows )
		{
			Enumeration E = windows.elements();
			while( E.hasMoreElements() )
			{
				ChatWindow window = (ChatWindow)E.nextElement();		
				if( window.to.equals(from) )
				{
					window.jabberPresence( nickname, presence );
					return true;
				}
			}
		}
		return false;
	}
	
	protected String getType()
	{
		return "groupchat";
	}
		
	/**
	 * Extracts the nickname (handle) from the message's "from" field.
	 */
	public String nickname( String jabberID )
	{
		int slash = jabberID.lastIndexOf('/');
		if( slash < 0 )
			return "";
		return jabberID.substring( slash + 1 );
	}	
}
