/*
* THIS SOFTWARE AND DOCUMENTATION ARE PROVIDED AS IS.  BITFLASH GRAPHICS INC.
* (BITFLASH) ASSUMES NO RESPONSIBILITY FOR THE ACCURACY OR COMPLETENESS OF THE
* DOCUMENTATION AND EXPRESSLY DISCLAIMS ALL REPRESENTATIONS AND WARRANTIES OF ANY
* KIND REGARDING THE CONTENT OR USE OF THE SOFTWARE OR DOCUMENTATION INCLUDING,
* BUT NOT LIMITED TO, EXPRESS AND IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS
* FOR A PARTICULAR USE, OR NON-INFRINGEMENT.
*
* IN NO EVENT WILL BITFLASH BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL,
* INCIDENTAL OR CONSEQUENTIAL DAMAGES, INCLUDING LOST PROFITS, LOST BUSINESS OR
* LOST DATA, RESULTING FROM THE USE OF OR RELIANCE UPON THE SOFTWARE OR
* DOCUMENTATION, WHETHER OR NOT BITFLASH HAS BEEN ADVISED OF THE POSSIBILITY OF
* SUCH DAMAGES.
*/

package com.bitflash.jabber.client.gui;

import java.awt.*;
import java.awt.event.*;
import com.bitflash.jabber.client.model.jabber.*;

/**
 * An input form for an instant message.
 */

class MessageDialog extends Dialog implements ActionListener
{		
	MessageDialog( Frame parent, String from, String to )
	{
		super( parent );
		
		this.from = from;
		this.to = to;
		this.subject = "";
		this.body = "";
		
		setModal( true );

		{
			GridLayout layout = new GridLayout(2,1);
			layout.setHgap( 10 );
			layout.setVgap( 10 );		
			setLayout( layout );
		}
		
		Panel addressPanel = new Panel();

		GridLayout addressLayout = new GridLayout(4,2);
		addressLayout.setHgap( 10 );
		addressLayout.setVgap( 10 );		
		addressPanel.setLayout( addressLayout );
				
		addressPanel.add( new Label("From: ") );
		addressPanel.add( new Label(Message.extractNickname(from)) );
		
		addressPanel.add( new Label("To: ") );
		addressPanel.add( new Label(Message.extractNickname(to)) );

		addressPanel.add( new Label("Subject: ") );
		addressPanel.add( fieldSubject = new TextField() );
		
		Button ok = new Button( "OK" );
		ok.addActionListener( this );
		ok.setName( "OK" );
		addressPanel.add( ok );

		Button cancel = new Button( "Cancel" );
		cancel.addActionListener( this );
		cancel.setName( "Cancel" );
		addressPanel.add( cancel );		
		
		add( addressPanel );		
		add( areaBody = new TextArea() );												
		
		pack();
	}
	
	public boolean open()
	{		
		fieldSubject.setText( subject );
		areaBody.setText( body );
		show();
		return accepted;
	}
			
	Message createMessage()
	{	
		Message message = new Message();				
		message.setProperty("from", from ); 
		message.setProperty("to", to );
		message.setProperty("subject", subject );
		message.setProperty("body", body ); 
		return message;
	}
	
	public void actionPerformed( ActionEvent event )
	{		
		String sourceName = ((Component)event.getSource()).getName();
		body = areaBody.getText();
		subject = fieldSubject.getText();
		accepted = ("OK" == sourceName) && ("" != body);
		dispose();
	}	

	String from;
	String to;	
	String subject;
	String body;
	
	TextField fieldSubject;
	TextArea areaBody;
	
	boolean accepted = false;
}
