/*
* THIS SOFTWARE AND DOCUMENTATION ARE PROVIDED AS IS.  BITFLASH GRAPHICS INC.
* (BITFLASH) ASSUMES NO RESPONSIBILITY FOR THE ACCURACY OR COMPLETENESS OF THE
* DOCUMENTATION AND EXPRESSLY DISCLAIMS ALL REPRESENTATIONS AND WARRANTIES OF ANY
* KIND REGARDING THE CONTENT OR USE OF THE SOFTWARE OR DOCUMENTATION INCLUDING,
* BUT NOT LIMITED TO, EXPRESS AND IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS
* FOR A PARTICULAR USE, OR NON-INFRINGEMENT.
*
* IN NO EVENT WILL BITFLASH BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL,
* INCIDENTAL OR CONSEQUENTIAL DAMAGES, INCLUDING LOST PROFITS, LOST BUSINESS OR
* LOST DATA, RESULTING FROM THE USE OF OR RELIANCE UPON THE SOFTWARE OR
* DOCUMENTATION, WHETHER OR NOT BITFLASH HAS BEEN ADVISED OF THE POSSIBILITY OF
* SUCH DAMAGES.
*/

package com.bitflash.jabber.client.gui;

import java.util.*;
import com.bitflash.jabber.client.model.jabber.*;

public class PrivateChatManager extends ChatManager
{
	public PrivateChatManager( Main parent )
	{
		super( parent );
		this.threadID = 1000;
	}
	
	ChatWindow createSession( String remoteJabberID )
	{
		// Synchronize on windows to synchronize threadID.
		synchronized( windows )
		{
			return super.createSession( remoteJabberID, Integer.toString( threadID++ ) );
		}
	}
	
	void unknownSession( Message message )
	{
		ChatWindow window = createSession( message.fromNickname(), (String)message.getProperty("thread") );
		dispatchMessage( window, message );
	}	
	
	boolean jabberPresence( Presence presence )
	{	
		String from = presence.fromNickname();
		String nickname = nickname( from );
		
		synchronized( windows )
		{
			Enumeration E = windows.elements();
			while( E.hasMoreElements() )
			{
				ChatWindow window = (ChatWindow)E.nextElement();
				if( window.to.equals(from) )
					window.jabberPresence( nickname, presence );
			}
		}
		return false;
	}
	
	public void sendMessage( ChatWindow window, String body )
	{
		if( body.equals("") )
			return;

		Message message = createMessage( window );
		message.setProperty( "body", body );		
		parent.send( message );
		
		// Fake message reflection for private chat. Groupchat
		// does this automagically from the server.
		dispatchMessage( window, message );
	}	
	
	protected String getType()
	{
		return "chat";
	}	

	/**
	 * Extracts the nickname (handle) from the message's "from" field.
	 */	
	public String nickname( String jabberID )
	{
		return bareNickname( jabberID );
	}	
		
	int threadID;
}
