/*
* THIS SOFTWARE AND DOCUMENTATION ARE PROVIDED AS IS.  BITFLASH GRAPHICS INC.
* (BITFLASH) ASSUMES NO RESPONSIBILITY FOR THE ACCURACY OR COMPLETENESS OF THE
* DOCUMENTATION AND EXPRESSLY DISCLAIMS ALL REPRESENTATIONS AND WARRANTIES OF ANY
* KIND REGARDING THE CONTENT OR USE OF THE SOFTWARE OR DOCUMENTATION INCLUDING,
* BUT NOT LIMITED TO, EXPRESS AND IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS
* FOR A PARTICULAR USE, OR NON-INFRINGEMENT.
*
* IN NO EVENT WILL BITFLASH BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL,
* INCIDENTAL OR CONSEQUENTIAL DAMAGES, INCLUDING LOST PROFITS, LOST BUSINESS OR
* LOST DATA, RESULTING FROM THE USE OF OR RELIANCE UPON THE SOFTWARE OR
* DOCUMENTATION, WHETHER OR NOT BITFLASH HAS BEEN ADVISED OF THE POSSIBILITY OF
* SUCH DAMAGES.
*/

package com.bitflash.jabber.client.gui;

import java.awt.*;
import java.awt.event.*;
import java.util.*;

/**
 * A basic table GUI control.
 */
public class Table extends Panel implements ItemListener, ItemSelectable, ActionListener
{
	public Table()
		{ this( false ); }
	
	public Table( boolean allowMultipleSelection )
	{
		this.columns = new Vector();
		this.itemListeners = new Vector();
		this.actionListeners = new Vector();
		this.allowMultipleSelection = allowMultipleSelection;
		this.setLayout( new FlowLayout() );
	}
	
	public List addColumn()
	{
		List column = new List();
		column.setMultipleMode( allowMultipleSelection );
		column.addItemListener( this );
		column.addActionListener( this );
		
		columns.addElement( column );
		setLayout( new GridLayout(1, columns.size()) );
		add( column );				
		
		return column;
	}
	
	public void addItemListener( ItemListener listener )
		{ itemListeners.addElement( listener ); }
	
	public void removeItemListener( ItemListener listener )
		{ itemListeners.removeElement( listener ); }

	public void addActionListener( ActionListener listener )
		{ actionListeners.addElement( listener ); }
	
	public void removeActionListener( ActionListener listener )
		{ actionListeners.removeElement( listener ); }
	
	public Object[] getSelectedObjects()
	{
		int selected[] = getSelectedIndexes();
		Object result[] = new Object[selected.length];
		for( int i = 0; i < selected.length; i++ )
			result[i] = getRow( selected[i] );
		return result;
	}

	public String[] getSelectedItem()
		{ return getRow(((List)columns.firstElement()).getSelectedIndex()); }
	
	public int getSelectedIndex()
		{ return ((List)columns.firstElement()).getSelectedIndex(); }
	
	public int[] getSelectedIndexes()
		{ return ((List)columns.firstElement()).getSelectedIndexes(); }		
	
	public String[] getRow( int row )
	{
		String result[] = new String[columns.size()];		
		for( int i = 0; i < columns.size(); i++ )
			result[i] = ((List)columns.elementAt(i)).getItem(row);								
		return result;
	}	
	
	public void addRow( String values[] )
	{
		for( int i = 0; i < values.length; i++ )
			((List)columns.elementAt(i)).add( values[i] );
	}

	public void addRow( String values[], int index )
	{
		for( int i = 0; i < values.length; i++ )
			((List)columns.elementAt(i)).add( values[i], index );
	}	
	
	public void setRow( int row, String values[] )
	{
		for( int i = 0; i < values.length; i++ )
			((List)columns.elementAt(i)).replaceItem( values[i], row );
	}
		
	public void setCell( int row, int column, String value )
		{ ((List)columns.elementAt(column)).replaceItem( value, row ); }		
	
	public void removeAll()
	{
		Enumeration E = columns.elements();
		while( E.hasMoreElements() )
			((List)E.nextElement()).removeAll();
	}

	public void select( int row )
	{
		Enumeration E = columns.elements();
		while( E.hasMoreElements() )
			((List)E.nextElement()).select( row );
	}	
	
	public void itemStateChanged( ItemEvent item )
	{
		int selected = ((List)item.getSource()).getSelectedIndex();
		Enumeration E = columns.elements();
		while( E.hasMoreElements() )
			((List)E.nextElement()).select( selected );
		
		ItemEvent event = new ItemEvent( this, item.getID(), getRow(selected), item.getStateChange() );
		Enumeration listeners = itemListeners.elements();
		while( listeners.hasMoreElements() )
			((ItemListener)listeners.nextElement()).itemStateChanged( event );			
	}

	public void actionPerformed( ActionEvent event )
	{
		ActionEvent newEvent = new ActionEvent( this, event.getID(), event.getActionCommand() );
		Enumeration listeners = actionListeners.elements();
		while( listeners.hasMoreElements() )
			((ActionListener)listeners.nextElement()).actionPerformed( newEvent );		
	}
	
	Vector columns;
	Vector itemListeners;
	Vector actionListeners;
	boolean allowMultipleSelection;
}
