/*
* THIS SOFTWARE AND DOCUMENTATION ARE PROVIDED AS IS.  BITFLASH GRAPHICS INC.
* (BITFLASH) ASSUMES NO RESPONSIBILITY FOR THE ACCURACY OR COMPLETENESS OF THE
* DOCUMENTATION AND EXPRESSLY DISCLAIMS ALL REPRESENTATIONS AND WARRANTIES OF ANY
* KIND REGARDING THE CONTENT OR USE OF THE SOFTWARE OR DOCUMENTATION INCLUDING,
* BUT NOT LIMITED TO, EXPRESS AND IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS
* FOR A PARTICULAR USE, OR NON-INFRINGEMENT.
*
* IN NO EVENT WILL BITFLASH BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL,
* INCIDENTAL OR CONSEQUENTIAL DAMAGES, INCLUDING LOST PROFITS, LOST BUSINESS OR
* LOST DATA, RESULTING FROM THE USE OF OR RELIANCE UPON THE SOFTWARE OR
* DOCUMENTATION, WHETHER OR NOT BITFLASH HAS BEEN ADVISED OF THE POSSIBILITY OF
* SUCH DAMAGES.
*/

package com.bitflash.jabber.client.gui.whiteboard;

import java.awt.*;

/**
 * Represents a handle in the Whiteboard GUI. Basically,
 * this is a control to allow users to move a particular
 * vertex around the whiteboard.
 */
class WhiteboardHandle
{
	static final int HANDLE_THICKNESS = 4;
	
	/**
	 * Vertex coordinates.
	 */
	public Point coordinates = new Point();
		
	/**
	 * Translates the handle on the plane by the given deltas,
	 * ala (x,y) => (x + deltaX, y + deltaY)
	 */
	public void translate( int deltaX, int deltaY )
	{
		coordinates.x += deltaX;
		coordinates.y += deltaY;
	}
		
	/**
	 * Updates the parent WhiteboardObject with the new coordinates.
	 */
	public void updateObject()
	{
		parent.updateFromHandle( this );
	}
		
	/**
	 * Returns true if the given point is on the handle.
	 */
	boolean detect( Point point )
	{
		return Math.abs(coordinates.x - point.x) <= HANDLE_THICKNESS 
					&& Math.abs(coordinates.y - point.y) <= HANDLE_THICKNESS;		
	}
	
	void paint( Graphics context )
	{
		parent.updateHandles();
		
		context.fillRect( 
			coordinates.x - HANDLE_THICKNESS, 
			coordinates.y - HANDLE_THICKNESS,
			HANDLE_THICKNESS*2,
			HANDLE_THICKNESS*2
		);		
	}
	
	/**
	 * The WhiteboardObject that owns this guy.
	 */
	WhiteboardObject parent;	
}
