/*
* THIS SOFTWARE AND DOCUMENTATION ARE PROVIDED AS IS.  BITFLASH GRAPHICS INC.
* (BITFLASH) ASSUMES NO RESPONSIBILITY FOR THE ACCURACY OR COMPLETENESS OF THE
* DOCUMENTATION AND EXPRESSLY DISCLAIMS ALL REPRESENTATIONS AND WARRANTIES OF ANY
* KIND REGARDING THE CONTENT OR USE OF THE SOFTWARE OR DOCUMENTATION INCLUDING,
* BUT NOT LIMITED TO, EXPRESS AND IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS
* FOR A PARTICULAR USE, OR NON-INFRINGEMENT.
*
* IN NO EVENT WILL BITFLASH BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL,
* INCIDENTAL OR CONSEQUENTIAL DAMAGES, INCLUDING LOST PROFITS, LOST BUSINESS OR
* LOST DATA, RESULTING FROM THE USE OF OR RELIANCE UPON THE SOFTWARE OR
* DOCUMENTATION, WHETHER OR NOT BITFLASH HAS BEEN ADVISED OF THE POSSIBILITY OF
* SUCH DAMAGES.
*/

package com.bitflash.jabber.client.gui.whiteboard;

import java.awt.*;
import com.bitflash.jabber.client.model.svg.*;
import com.bitflash.jabber.client.model.*;

public class WhiteboardLine extends WhiteboardObject	
{
	static final int LINE_THICKNESS = WhiteboardHandle.HANDLE_THICKNESS;
	
	public WhiteboardLine( WhiteboardModel model, DocumentObject line )
	{
		super( model, line );
		
		startHandle = new WhiteboardHandle();
		endHandle = new WhiteboardHandle();
		
		registerHandle( startHandle );
		registerHandle( endHandle );
	}	
	
	public boolean detect( Point point )
	{
		Line line = (Line)svgObject;
		return line.contains( point, LINE_THICKNESS );
	}
	
	public boolean isSingularity()
	{
		Line line = (Line)svgObject;
		return 0 == line.length();
	}
	
	public void paint( Graphics context )
	{
		Line line = (Line)svgObject;
		
		if( isForeignSelected() )
			context.setColor( Color.red );
		else
			context.setColor( Color.black );
		
		context.drawLine( line.x1(), line.y1(), line.x2(), line.y2() );		
		
		if( isSelected() )
		{
			startHandle.paint( context );
			endHandle.paint( context );			
		}			
		
		context.setColor( Color.black );
	}
	
	protected void updateHandles()
	{
		Line line = (Line)svgObject;
		
		startHandle.coordinates = line.getStart();		
		endHandle.coordinates = line.getEnd();
	}
	
	void updateFromHandle( WhiteboardHandle handle )
	{
		Line line = (Line)svgObject;
		
		if( startHandle == handle )
		{
			line.setStart( handle.coordinates );
		}
		
		else if( endHandle == handle )
		{
			line.setEnd( handle.coordinates );
		}
	}
	
	protected final WhiteboardHandle startHandle;
	protected final WhiteboardHandle endHandle;
}
