/*
* THIS SOFTWARE AND DOCUMENTATION ARE PROVIDED AS IS.  BITFLASH GRAPHICS INC.
* (BITFLASH) ASSUMES NO RESPONSIBILITY FOR THE ACCURACY OR COMPLETENESS OF THE
* DOCUMENTATION AND EXPRESSLY DISCLAIMS ALL REPRESENTATIONS AND WARRANTIES OF ANY
* KIND REGARDING THE CONTENT OR USE OF THE SOFTWARE OR DOCUMENTATION INCLUDING,
* BUT NOT LIMITED TO, EXPRESS AND IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS
* FOR A PARTICULAR USE, OR NON-INFRINGEMENT.
*
* IN NO EVENT WILL BITFLASH BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL,
* INCIDENTAL OR CONSEQUENTIAL DAMAGES, INCLUDING LOST PROFITS, LOST BUSINESS OR
* LOST DATA, RESULTING FROM THE USE OF OR RELIANCE UPON THE SOFTWARE OR
* DOCUMENTATION, WHETHER OR NOT BITFLASH HAS BEEN ADVISED OF THE POSSIBILITY OF
* SUCH DAMAGES.
*/

package com.bitflash.jabber.client.model;

import com.bitflash.jabber.client.xml.*;
import java.util.*;

public class DocumentObject extends XMLElement
{	
	static final Integer PROPERTY = new Integer(0);
	static final Integer SUBPROPERTY = new Integer(1);
	static final Integer SUBELEMENT = new Integer(2);
	
	static final String PROPERTIES[] = {
		"id",
		"xmlns",
	};
		
	public DocumentObject( String name )
	{
		super( name.toLowerCase() );
		
		attributeTypes = new Hashtable();
		addProperties( PROPERTIES );
	}
		
	public void addProperties( String names[] )
	{
		for( int i = 0; i < names.length; i++ )
			attributeTypes.put( names[i].toLowerCase(), PROPERTY );
	}
	
	public void addSubproperties( String names[] )
	{
		for( int i = 0; i < names.length; i++ )
			attributeTypes.put( names[i].toLowerCase(), SUBPROPERTY );
	}
	
	public void addSubelements( String names[] )
	{
		for( int i = 0; i < names.length; i++ )
			attributeTypes.put( names[i].toLowerCase(), SUBELEMENT );
	}

	public Object getProperty( String name )
	{
		String _name = name.toLowerCase();
		if( attributeTypes.containsKey( _name ) )
		{
			Integer type = (Integer)attributeTypes.get( _name );
			if( PROPERTY == type )
				return getAttribute(name);
			
			if( SUBPROPERTY == type )
			{
				XMLElement child = getChild( _name );
				if( null == child )
					return "";
				return child.getCharacterData();
			}
			
			if( SUBELEMENT == type )
				return getChild( _name );
		}
		return null;
	}
	
	public void setProperty( String name, Object data )
	{
		String _name = name.toLowerCase();
		if( !attributeTypes.containsKey( _name ) )
			return;
		
		Integer type = (Integer)attributeTypes.get( _name );
	
		if( SUBPROPERTY == type )
		{
			XMLElement child = getChild( _name );
			if( null == child )
			{
				child = new XMLElement( _name );
				addChild(child);
			}
			
			if( data instanceof XMLElement )
				child.setCharacterData( ((XMLElement)data).getCharacterData() );
			
			else			
				child.setCharacterData( (String)data );
		}
		
		else if( SUBELEMENT == type )
		{
			removeChild( _name );
			addChild( (XMLElement)data );
		}
		
		else // if PROPERTY == type
		{
			setAttribute( _name, (String)data );			
		}
	}
	
	public void setProperties( XMLElement source )
	{
		Enumeration keys = source.attributes.keys();
		while( keys.hasMoreElements() )
		{
			String key = (String)keys.nextElement();
			setProperty( key, source.attributes.get(key) );
		}
		
		Enumeration children = source.children.elements();
		while( children.hasMoreElements() )
		{
			XMLElement child = (XMLElement)children.nextElement();
			setProperty( child.name, child );
		}
	}
	
	protected boolean isAttributePrintable( String key, String value ) { return value.length() > 0; }
	protected boolean isChildPrintable( XMLElement child ) 
	{ 		
		return 
			!attributeTypes.containsKey( child.name ) 
			|| !(SUBPROPERTY == attributeTypes.get(child.name) && child.getCharacterData().length() == 0);
	}	
	
	Hashtable attributeTypes;	
}