/*
* THIS SOFTWARE AND DOCUMENTATION ARE PROVIDED AS IS.  BITFLASH GRAPHICS INC.
* (BITFLASH) ASSUMES NO RESPONSIBILITY FOR THE ACCURACY OR COMPLETENESS OF THE
* DOCUMENTATION AND EXPRESSLY DISCLAIMS ALL REPRESENTATIONS AND WARRANTIES OF ANY
* KIND REGARDING THE CONTENT OR USE OF THE SOFTWARE OR DOCUMENTATION INCLUDING,
* BUT NOT LIMITED TO, EXPRESS AND IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS
* FOR A PARTICULAR USE, OR NON-INFRINGEMENT.
*
* IN NO EVENT WILL BITFLASH BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL,
* INCIDENTAL OR CONSEQUENTIAL DAMAGES, INCLUDING LOST PROFITS, LOST BUSINESS OR
* LOST DATA, RESULTING FROM THE USE OF OR RELIANCE UPON THE SOFTWARE OR
* DOCUMENTATION, WHETHER OR NOT BITFLASH HAS BEEN ADVISED OF THE POSSIBILITY OF
* SUCH DAMAGES.
*/

package com.bitflash.jabber.client.model.jabber;
import com.bitflash.jabber.client.model.*;
import com.bitflash.jabber.client.xml.*;

/**
 * Represents the <iq/> element in the Jabber XML stream.
 */

public class InfoQuery extends DocumentObject
{
	static final String PROPERTIES[] = {
		"type",
		"id",				
	};
	
	static final String SUBELEMENTS[] = {
		"error",
		"query",
	};	
	
	InfoQuery()
	{
		super( "iq" );
		
		addProperties( PROPERTIES );
		addSubelements( SUBELEMENTS  );
		setProperty( "type", "set" );		
	}
		
	/**
	 * Extracts the nickname from a full Jabber ID.
	 * @param jabberID the jabberID
	 * @return the nickname, of the form handle@host
	 */
	static public String extractNickname( String jabberID )
	{
		int slash = jabberID.lastIndexOf('/');
		if( slash < 0 )
			return jabberID;
		return jabberID.substring( 0, slash );		
	}	
	
	static public DocumentObject compile( XMLElement xmlElement )
	{
		InfoQuery iq = new InfoQuery();
		iq.setProperties( xmlElement );
		
		String type = (String)xmlElement.getAttribute( "type" );
		
		if( type.equals( "error" ) )
		{
			XMLElement child = xmlElement.getChild("error");
			if( null == child )
				return null;			
			Error error = (Error)Error.compile( child );
			iq.setProperty( "error", error );
			return error;
		}
			
		if( type.equals( "result" ) )	
		{
			XMLElement query = xmlElement.getChild("query", "jabber:iq:roster");
			
			if( null != query )
			{
				Roster roster = (Roster)Roster.compile( query );
				iq.setProperty( "query", roster );
				return roster;
			}
		}
				
		return iq;
	}	
}
