/*
* THIS SOFTWARE AND DOCUMENTATION ARE PROVIDED AS IS.  BITFLASH GRAPHICS INC.
* (BITFLASH) ASSUMES NO RESPONSIBILITY FOR THE ACCURACY OR COMPLETENESS OF THE
* DOCUMENTATION AND EXPRESSLY DISCLAIMS ALL REPRESENTATIONS AND WARRANTIES OF ANY
* KIND REGARDING THE CONTENT OR USE OF THE SOFTWARE OR DOCUMENTATION INCLUDING,
* BUT NOT LIMITED TO, EXPRESS AND IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS
* FOR A PARTICULAR USE, OR NON-INFRINGEMENT.
*
* IN NO EVENT WILL BITFLASH BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL,
* INCIDENTAL OR CONSEQUENTIAL DAMAGES, INCLUDING LOST PROFITS, LOST BUSINESS OR
* LOST DATA, RESULTING FROM THE USE OF OR RELIANCE UPON THE SOFTWARE OR
* DOCUMENTATION, WHETHER OR NOT BITFLASH HAS BEEN ADVISED OF THE POSSIBILITY OF
* SUCH DAMAGES.
*/

package com.bitflash.jabber.client.model.jabber;
import com.bitflash.jabber.client.model.*;
import com.bitflash.jabber.client.xml.*;

/**
 *  Represents a <message/> element in the Jabber XML stream.
 */

public class Message extends DocumentObject 
{
	static final String PROPERTIES[] = {
		"to",
		"from",
		"type",
		"id",
	};
		
	static final String SUBPROPERTIES[] = {
		"body",
		"thread",
		"subject",
	};	 	
	
	static final String SUBELEMENTS[] = {
		"error",
	};
	
	public Message()
	{
		super( "message" );
		
		addProperties( PROPERTIES );
		addSubproperties( SUBPROPERTIES );
		addSubelements( SUBELEMENTS );
		
		setProperty( "type", "normal" );		
	}
	
	public String fromNickname() 
		{ return extractNickname((String)getProperty("from")); }
	
	public String toNickname()
		{ return extractNickname((String)getProperty("to")); }		
		
	static public String extractNickname( String jabberID )
	{
		int slash = jabberID.lastIndexOf('/');
		if( slash < 0 )
			return jabberID;
		return jabberID.substring( 0, slash );		
	}		
	
	static public DocumentObject compile( XMLElement xmlElement )
	{
		Message message = new Message();
		message.setProperties( xmlElement );
		
		XMLElement xmlError = xmlElement.getChild( "error" );
		if( xmlError != null )
		{
			Error error = (Error)Error.compile( xmlError );
			message.setProperty( error.name, error );
			return error;
		}
		
		XMLElement x = xmlElement.getChild( "x", X.XMLNS_WHITEBOARD );
		if( null != x )
		{			
			DocumentObject child = X.compile(x);
			if( null != child )
				message.addChild( child );
		}
		
		return message;
	}
}