/*
* THIS SOFTWARE AND DOCUMENTATION ARE PROVIDED AS IS.  BITFLASH GRAPHICS INC.
* (BITFLASH) ASSUMES NO RESPONSIBILITY FOR THE ACCURACY OR COMPLETENESS OF THE
* DOCUMENTATION AND EXPRESSLY DISCLAIMS ALL REPRESENTATIONS AND WARRANTIES OF ANY
* KIND REGARDING THE CONTENT OR USE OF THE SOFTWARE OR DOCUMENTATION INCLUDING,
* BUT NOT LIMITED TO, EXPRESS AND IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS
* FOR A PARTICULAR USE, OR NON-INFRINGEMENT.
*
* IN NO EVENT WILL BITFLASH BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL,
* INCIDENTAL OR CONSEQUENTIAL DAMAGES, INCLUDING LOST PROFITS, LOST BUSINESS OR
* LOST DATA, RESULTING FROM THE USE OF OR RELIANCE UPON THE SOFTWARE OR
* DOCUMENTATION, WHETHER OR NOT BITFLASH HAS BEEN ADVISED OF THE POSSIBILITY OF
* SUCH DAMAGES.
*/

package com.bitflash.jabber.client.model.jabber;

import java.util.*;
import com.bitflash.jabber.client.model.*;
import com.bitflash.jabber.client.xml.*;

/**
 * Represents a <presence/> element in the Jabber XML stream.
 */
public class Presence extends DocumentObject
{
	static final String PROPERTIES[] = {
		"from",
		"to",
		"type",		
	};
	
	static final String SUBPROPERTIES[] = {
		"priority",
		"show",
		"status",
		"thread",		
	};
		
	public Presence()
	{
		super( "presence" );
		
		addProperties( PROPERTIES );
		addSubproperties( SUBPROPERTIES );
		
		setProperty( "type", "available" );
		setProperty( "priority", "0" );
		setProperty( "show", "" );
	}
	
	static public Presence create( String user, String server, String resource )
	{	
		Presence result = new Presence();
		result.setProperty( "from", user + "@" + server + "/" + resource );		
		return result;
	}
	
	public String status()
	{
		String status = (String)getProperty("show");
		if( status.equals("") )
			status = (String)getProperty("status");
		if( status.equals("") )
			status = (String)getProperty("type");
		return status;
	}
	
	public String fromNickname() 
		{ return extractNickname((String)getProperty("from")); }
	
	public String toNickname()
		{ return extractNickname((String)getProperty("to")); }		
		
	static public String extractNickname( String jabberID )
	{
		int slash = jabberID.lastIndexOf('/');
		if( slash < 0 )
			return jabberID;
		return jabberID.substring( 0, slash );		
	}	
	
	static public DocumentObject compile( XMLElement xmlElement )
	{
		// "<from> is composing a reply." message. TODO: Do something fun with this.
		if( null != xmlElement.getChild("x", X.XMLNS_COMPOSE_REPLY) )
		   return null;				
		
		Presence result = new Presence();
		result.setProperties( xmlElement );
		
		XMLElement x = xmlElement.getChild( "x", X.XMLNS_WHITEBOARD );
		if( null != x )
		{			
			DocumentObject child = X.compile(x);
			if( null != child )
				result.addChild( child );
		}
				
		return result;
	}	
}
