/*
* THIS SOFTWARE AND DOCUMENTATION ARE PROVIDED AS IS.  BITFLASH GRAPHICS INC.
* (BITFLASH) ASSUMES NO RESPONSIBILITY FOR THE ACCURACY OR COMPLETENESS OF THE
* DOCUMENTATION AND EXPRESSLY DISCLAIMS ALL REPRESENTATIONS AND WARRANTIES OF ANY
* KIND REGARDING THE CONTENT OR USE OF THE SOFTWARE OR DOCUMENTATION INCLUDING,
* BUT NOT LIMITED TO, EXPRESS AND IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS
* FOR A PARTICULAR USE, OR NON-INFRINGEMENT.
*
* IN NO EVENT WILL BITFLASH BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL,
* INCIDENTAL OR CONSEQUENTIAL DAMAGES, INCLUDING LOST PROFITS, LOST BUSINESS OR
* LOST DATA, RESULTING FROM THE USE OF OR RELIANCE UPON THE SOFTWARE OR
* DOCUMENTATION, WHETHER OR NOT BITFLASH HAS BEEN ADVISED OF THE POSSIBILITY OF
* SUCH DAMAGES.
*/

package com.bitflash.jabber.client.model.jabber;

/**
 * Represents a jabber:iq:roster <iq> (info/query) request/result
 * in the Jabber XML stream. 
 */

import java.util.*;
import com.bitflash.jabber.client.model.*;
import com.bitflash.jabber.client.xml.*;

public class Roster extends Query
{	
	static final String ITEM_PROPERTIES[] = {
		"name",
		"jid",
	};

	static final String ITEM_SUBPROPERTIES[] = {
		"group",
	};	
	
	public class Item extends DocumentObject
	{			
		public Item()
		{
			super( "item" );
			addProperties( ITEM_PROPERTIES );
			addSubproperties( ITEM_SUBPROPERTIES );
		}
		
		public Presence asPresence()
		{
			Presence presence = new Presence();
			presence.setProperty( "from", getProperty("jid") );
			presence.setProperty( "status", "unavailable" );
			return presence;
		}
	}
		
	public Roster()
	{
		super( "jabber:iq:roster" );		
	}
	
	static public InfoQuery createRequest()
	{
		Roster roster = new Roster();		
		
		InfoQuery iq = new InfoQuery();
		iq.setProperty( roster.name, roster );
		iq.setProperty( "type", "get" );
		return iq;
	}
			
	static public DocumentObject compile( XMLElement xmlElement )
	{
		Roster result = new Roster();
		result.setProperties( xmlElement );
		
		Enumeration E = xmlElement.children.elements();
		while( E.hasMoreElements() )
		{
			XMLElement xmlItem = (XMLElement)E.nextElement();
			if( !xmlItem.name.equals("item") )
				continue;

			Item item = result.new Item();
            item.setProperties( xmlItem );
			result.addChild( item );
		}
		return result;
	}
}
