/*
* THIS SOFTWARE AND DOCUMENTATION ARE PROVIDED AS IS.  BITFLASH GRAPHICS INC.
* (BITFLASH) ASSUMES NO RESPONSIBILITY FOR THE ACCURACY OR COMPLETENESS OF THE
* DOCUMENTATION AND EXPRESSLY DISCLAIMS ALL REPRESENTATIONS AND WARRANTIES OF ANY
* KIND REGARDING THE CONTENT OR USE OF THE SOFTWARE OR DOCUMENTATION INCLUDING,
* BUT NOT LIMITED TO, EXPRESS AND IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS
* FOR A PARTICULAR USE, OR NON-INFRINGEMENT.
*
* IN NO EVENT WILL BITFLASH BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL,
* INCIDENTAL OR CONSEQUENTIAL DAMAGES, INCLUDING LOST PROFITS, LOST BUSINESS OR
* LOST DATA, RESULTING FROM THE USE OF OR RELIANCE UPON THE SOFTWARE OR
* DOCUMENTATION, WHETHER OR NOT BITFLASH HAS BEEN ADVISED OF THE POSSIBILITY OF
* SUCH DAMAGES.
*/

package com.bitflash.jabber.client.model.jabber;

import com.bitflash.jabber.client.model.*;
import com.bitflash.jabber.client.model.svg.*;
import com.bitflash.jabber.client.xml.*;

/**
 * Represents an <x/> element in the Jabber XML stream.
 * Really, this is generic, do what you want XML space.
 * The "x" stands for "extension."
 */

public class X extends DocumentObject
{
	static public final String XMLNS_COMPOSE_REPLY = "jabber:x:replypres";
	static public final String XMLNS_DELAY = "jabber:x:delay";
	static public final String XMLNS_WHITEBOARD = "com:bitflash:jabber:whiteboard";
	
	static final String PROPERTIES[] = {
		"action",
		"to",
		"acknowledge",
	};
	
	static final String SUBELEMENTS[] = {
		"svg",
	};	
	
	public X( String xmlns )
	{
		super( "x" );
		
		addProperties( PROPERTIES );
		addSubelements( SUBELEMENTS );
		
		setProperty( "xmlns", xmlns );
	}	
	
	static public DocumentObject compile( XMLElement xmlElement )
	{
		if( !xmlElement.hasAttribute("xmlns") )
			return null;
		
		String xmlns = xmlElement.getAttribute("xmlns").toLowerCase();
		if( xmlns.equals( XMLNS_WHITEBOARD ) )
		{
			X result = new X( XMLNS_WHITEBOARD );
			result.setProperties( xmlElement );
			
			XMLElement svg = xmlElement.getChild("svg");
			if( null != svg )
			{
				DocumentObject compiled = SVG.compile( svg );
				if( null == compiled )
					return null;
							
				result.setProperty( "svg", compiled );
			}
			return result;
		}
		
		return null;
	}
}
