/*
* THIS SOFTWARE AND DOCUMENTATION ARE PROVIDED AS IS.  BITFLASH GRAPHICS INC.
* (BITFLASH) ASSUMES NO RESPONSIBILITY FOR THE ACCURACY OR COMPLETENESS OF THE
* DOCUMENTATION AND EXPRESSLY DISCLAIMS ALL REPRESENTATIONS AND WARRANTIES OF ANY
* KIND REGARDING THE CONTENT OR USE OF THE SOFTWARE OR DOCUMENTATION INCLUDING,
* BUT NOT LIMITED TO, EXPRESS AND IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS
* FOR A PARTICULAR USE, OR NON-INFRINGEMENT.
*
* IN NO EVENT WILL BITFLASH BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL,
* INCIDENTAL OR CONSEQUENTIAL DAMAGES, INCLUDING LOST PROFITS, LOST BUSINESS OR
* LOST DATA, RESULTING FROM THE USE OF OR RELIANCE UPON THE SOFTWARE OR
* DOCUMENTATION, WHETHER OR NOT BITFLASH HAS BEEN ADVISED OF THE POSSIBILITY OF
* SUCH DAMAGES.
*/

package com.bitflash.jabber.client.model.svg;

import java.awt.Point;
import com.bitflash.jabber.client.model.*;
import com.bitflash.jabber.client.xml.*;


public class Line extends DocumentObject
{	
	static final String PROPERTIES[] = {
		"x1",
		"y1",
		"x2",
		"y2",
	};
		
	public Line()
	{
		super( "line" );
		addProperties( PROPERTIES );
		x1(0); 
		y1(0); 
		x2(0); 
		y2(0);
	}
	
	public Line( Point start, Point end )
	{
		this();
		setStart(start);
		setEnd(end);
	}

	public int x1() { return Integer.parseInt( (String)getProperty("x1") ); }
	public int y1() { return Integer.parseInt( (String)getProperty("y1") ); }
	public int x2() { return Integer.parseInt( (String)getProperty("x2") ); }
	public int y2() { return Integer.parseInt( (String)getProperty("y2") ); }
	
	public void x1( int v ) { setProperty( "x1", Integer.toString(v) ); }
	public void y1( int v ) { setProperty( "y1", Integer.toString(v) ); }
	public void x2( int v ) { setProperty( "x2", Integer.toString(v) ); }
	public void y2( int v ) { setProperty( "y2", Integer.toString(v) ); }
	
	public void setStart( Point start )
	{
		x1(start.x); y1(start.y);
	}	
	
	public void setEnd( Point end )
	{
		x2(end.x); y2(end.y);
	}
		
	public Point getStart()
	{
		return new Point( x1(), y1() );
	}
	
	public Point getEnd()
	{
		return new Point( x2(), y2() );
	}
	
	public boolean contains( java.awt.Point point, int tolerance ) 
	{
		int x1 = x1();
		int y1 = y1();
		int x2 = x2();
		int y2 = y2();
		
		// Outside bounding rectangle?
		if( Math.min( x1, x2 ) - tolerance > point.x ||
			Math.max( x2, x1 ) + tolerance < point.x ||
			Math.min( y1, y2 ) - tolerance > point.y ||
			Math.max( y2, y1 ) + tolerance < point.y )			   
			return false;
			
		int directionX = x2 - x1;
		int directionY = y2 - y1;			
		int vX = point.x - x1;
		int vY = point.y - y1;
			
		long lengthSquared = directionX * directionX + directionY * directionY;
		long distanceSquared;
			
		if( 0 == lengthSquared )
		{
			distanceSquared = vX * vX + vY * vY;
		}
		else
		{			
			long cross = (vX * directionY - vY * directionX);
			distanceSquared = cross * cross / 
			  (directionX * directionX + directionY * directionY);
		}
			
		return tolerance * tolerance  >= distanceSquared;
	}
	
	public double length()
	{
		int deltaX = x1() - x2();
		int deltaY = y1() - y2();
		return Math.sqrt( deltaX * deltaX + deltaY * deltaY );
	}	
		
	static public DocumentObject compile( XMLElement xmlElement )
	{
		Line result = new Line();
		result.setProperties( xmlElement );
		return result;
	}
}
