/*
* THIS SOFTWARE AND DOCUMENTATION ARE PROVIDED AS IS.  BITFLASH GRAPHICS INC.
* (BITFLASH) ASSUMES NO RESPONSIBILITY FOR THE ACCURACY OR COMPLETENESS OF THE
* DOCUMENTATION AND EXPRESSLY DISCLAIMS ALL REPRESENTATIONS AND WARRANTIES OF ANY
* KIND REGARDING THE CONTENT OR USE OF THE SOFTWARE OR DOCUMENTATION INCLUDING,
* BUT NOT LIMITED TO, EXPRESS AND IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS
* FOR A PARTICULAR USE, OR NON-INFRINGEMENT.
*
* IN NO EVENT WILL BITFLASH BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL,
* INCIDENTAL OR CONSEQUENTIAL DAMAGES, INCLUDING LOST PROFITS, LOST BUSINESS OR
* LOST DATA, RESULTING FROM THE USE OF OR RELIANCE UPON THE SOFTWARE OR
* DOCUMENTATION, WHETHER OR NOT BITFLASH HAS BEEN ADVISED OF THE POSSIBILITY OF
* SUCH DAMAGES.
*/

package com.bitflash.jabber.client.xml;

import java.util.*;
import java.io.*;

/**
 * Represents one element in an XML tree. The much more
 * powerful version of this class is 
 *     com.bitflash.jabber.client.model.Documentobject.
 */
public class XMLElement 
{	
	public XMLElement( String name )
	{
		this.name = name.toLowerCase();				
		this.characterData = new StringBuffer();
		this.children = new Vector();		
		this.attributes = new Hashtable();
	}
	
	public String getName() { return name; }
	
	public void setAttribute( String name, String value )
		{ attributes.put( name.toLowerCase(), value ); }

	public String getAttribute( String name )
	{ 
		String _name = name.toLowerCase();
		if( !attributes.containsKey( _name ) )
			return "";										 
		return (String)attributes.get( _name ); 
	}
	
	public boolean hasAttribute( String name )
		{ return attributes.containsKey( name.toLowerCase() ); }	
	
	public void appendCharacterData( String data ) 
		{ characterData.append( data ); }
	
	public String getCharacterData() 
		{ return characterData.toString(); }
	
	public void setCharacterData( String data ) 
		{ characterData = new StringBuffer(data); }			
	
	public void addChild( XMLElement child ) 
	{ 
		children.addElement(child); 
		child.parent = this; 
	}	
	
	public XMLElement getChild( String tag )
		{ return getChild( tag, "" ); }
	
	public XMLElement getChild( String tag, String xmlns )
	{
		String _tag = tag.toLowerCase();
		String _xmlns = xmlns.toLowerCase();
		
		Enumeration E = children.elements();
		while( E.hasMoreElements() )
		{
			XMLElement child = (XMLElement)E.nextElement();
			if( child.name.equals(_tag) && child.getAttribute("xmlns").equals(_xmlns) )
				return child;
		}
		return null;
	}	
	
	public Vector getChildren( String tag )
		{ return getChildren( tag, "" ); }
	
	public Vector getChildren( String tag, String xmlns )
	{
		String _tag = tag.toLowerCase();
		String _xmlns = xmlns.toLowerCase();
		
		Vector result = new Vector();
		
		Enumeration E = children.elements();
		while( E.hasMoreElements() )
		{
			XMLElement child = (XMLElement)E.nextElement();
			if( child.name.equals(_tag) && child.getAttribute("xmlns").equals(_xmlns) )
				result.addElement(child);
		}
		return result;
	}	
	
	public XMLElement removeChild( XMLElement child )
	{
		children.removeElement( child );
		child.parent = null;
		return child;
	}
	
	public XMLElement removeChild( String tag )
	{
		XMLElement child = getChild(tag);
		if( null == child )
			return null;
		return removeChild( child );
	}
	
	/**
	 * Returns an XML element with just the tag name and the ID
	 */
	public XMLElement idOnly()							  
	{
		XMLElement result = new XMLElement(name);
		result.setAttribute("id", getAttribute("id"));
		return result;
	}
		
	public String toString()
	{
		StringBuffer result = new StringBuffer();
		result.append( "<" );
		result.append( name );
		
		Enumeration keys = attributes.keys();
		while( keys.hasMoreElements() )
		{
			String key = (String)keys.nextElement();
			String value = (String)attributes.get( key );
						
			if( isAttributePrintable( key, value ) )
			{
				result.append( " " );
				result.append( key );
				result.append( "=\"" );
				result.append( StreamingXMLParser.encodeUTF(value) );
				result.append( "\"" );
			}
		}
				
		if( children.isEmpty() && 0 == characterData.length() )
		{
			result.append( "/>" );
		}
		
		else
		{
			result.append( ">" );
			result.append( StreamingXMLParser.encodeUTF(characterData.toString()) );
			
			Enumeration E = children.elements();
			while( E.hasMoreElements() )
			{
				XMLElement child = (XMLElement)E.nextElement();
				if( isChildPrintable(child) )
					result.append( child.toString() );
			}
			
			result.append( "</" );
			result.append( name );
			result.append( ">" );
		}
		
		return result.toString();
	}	
	
	protected boolean isAttributePrintable( String key, String value ) { return true; }
	protected boolean isChildPrintable( XMLElement child ) { return true; }
	
	public String name;
	public Hashtable attributes;
	public StringBuffer characterData;
	public Vector children;	
	public XMLElement parent;	
}
